/* Generated by wayland-scanner 1.22.0 */

#ifndef COLOR_MANAGEMENT_V1_CLIENT_PROTOCOL_H
#define COLOR_MANAGEMENT_V1_CLIENT_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-client.h"

#ifdef  __cplusplus
extern "C" {
#endif

/**
 * @page page_color_management_v1 The color_management_v1 protocol
 * color management protocol
 *
 * @section page_desc_color_management_v1 Description
 *
 * The aim of the color management extension is to allow clients to know
 * the color properties of outputs, and to tell the compositor about the color
 * properties of their content on surfaces. Doing this enables a compositor
 * to perform automatic color management of content for different outputs
 * according to how content is intended to look like.
 *
 * The color properties are represented as an image description object which
 * is immutable after it has been created. A wl_output always has an
 * associated image description that clients can observe. A wl_surface
 * always has an associated preferred image description as a hint chosen by
 * the compositor that clients can also observe. Clients can set an image
 * description on a wl_surface to denote the color characteristics of the
 * surface contents.
 *
 * An image description includes SDR and HDR colorimetry and encoding, HDR
 * metadata, and viewing environment parameters. An image description does
 * not include the properties set through color-representation extension.
 * It is expected that the color-representation extension is used in
 * conjunction with the color management extension when necessary,
 * particularly with the YUV family of pixel formats.
 *
 * Recommendation ITU-T H.273
 * "Coding-independent code points for video signal type identification"
 * shall be referred to as simply H.273 here, and it defines the CICP values.
 *
 * The color-and-hdr repository
 * (https://gitlab.freedesktop.org/pq/color-and-hdr) contains
 * background information on the protocol design and legacy color management.
 * It also contains a glossary, learning resources for digital color, tools,
 * samples and more.
 *
 * The terminology used in this protocol is based on common color science and
 * color encoding terminology where possible. The glossary in the color-and-hdr
 * repository shall be the authority on the definition of terms in this
 * protocol.
 *
 * @section page_ifaces_color_management_v1 Interfaces
 * - @subpage page_iface_wp_color_manager_v1 - color manager singleton
 * - @subpage page_iface_wp_color_management_output_v1 - output color properties
 * - @subpage page_iface_wp_color_management_surface_v1 - color management extension to a surface
 * - @subpage page_iface_wp_image_description_creator_icc_v1 - holder of image description ICC information
 * - @subpage page_iface_wp_image_description_creator_params_v1 - holder of image description parameters
 * - @subpage page_iface_wp_image_description_v1 - Colorimetric image description
 * @section page_copyright_color_management_v1 Copyright
 * <pre>
 *
 * Copyright 2019 Sebastian Wick
 * Copyright 2019 Erwin Burema
 * Copyright 2020 AMD
 * Copyright 2020, 2022, 2023 Collabora, Ltd.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 * </pre>
 */
struct wl_output;
struct wl_surface;
struct wp_color_management_output_v1;
struct wp_color_management_surface_v1;
struct wp_color_manager_v1;
struct wp_image_description_creator_icc_v1;
struct wp_image_description_creator_params_v1;
struct wp_image_description_v1;

#ifndef WP_COLOR_MANAGER_V1_INTERFACE
#define WP_COLOR_MANAGER_V1_INTERFACE
/**
 * @page page_iface_wp_color_manager_v1 wp_color_manager_v1
 * @section page_iface_wp_color_manager_v1_desc Description
 *
 * A global interface used for getting color management extensions for
 * wl_surface and wl_output objects, and for creating client defined image
 * description objects. The extension interfaces allow
 * getting the image description of outputs and setting the image
 * description of surfaces.
 * @section page_iface_wp_color_manager_v1_api API
 * See @ref iface_wp_color_manager_v1.
 */
/**
 * @defgroup iface_wp_color_manager_v1 The wp_color_manager_v1 interface
 *
 * A global interface used for getting color management extensions for
 * wl_surface and wl_output objects, and for creating client defined image
 * description objects. The extension interfaces allow
 * getting the image description of outputs and setting the image
 * description of surfaces.
 */
extern const struct wl_interface wp_color_manager_v1_interface;
#endif
#ifndef WP_COLOR_MANAGEMENT_OUTPUT_V1_INTERFACE
#define WP_COLOR_MANAGEMENT_OUTPUT_V1_INTERFACE
/**
 * @page page_iface_wp_color_management_output_v1 wp_color_management_output_v1
 * @section page_iface_wp_color_management_output_v1_desc Description
 *
 * A wp_color_management_output_v1 describes the color properties of an
 * output.
 *
 * When wp_color_management_output_v1 object is created, it will send
 * its initial events followed by a wl_output.done event. When creating
 * wl_output and its extension objects, use a final wl_display.sync to
 * guarantee that all output events have been received across all
 * extensions.
 *
 * If the wl_output associated with the wp_color_management_output_v1 is
 * destroyed, the wp_color_management_output_v1 object becomes inert.
 * @section page_iface_wp_color_management_output_v1_api API
 * See @ref iface_wp_color_management_output_v1.
 */
/**
 * @defgroup iface_wp_color_management_output_v1 The wp_color_management_output_v1 interface
 *
 * A wp_color_management_output_v1 describes the color properties of an
 * output.
 *
 * When wp_color_management_output_v1 object is created, it will send
 * its initial events followed by a wl_output.done event. When creating
 * wl_output and its extension objects, use a final wl_display.sync to
 * guarantee that all output events have been received across all
 * extensions.
 *
 * If the wl_output associated with the wp_color_management_output_v1 is
 * destroyed, the wp_color_management_output_v1 object becomes inert.
 */
extern const struct wl_interface wp_color_management_output_v1_interface;
#endif
#ifndef WP_COLOR_MANAGEMENT_SURFACE_V1_INTERFACE
#define WP_COLOR_MANAGEMENT_SURFACE_V1_INTERFACE
/**
 * @page page_iface_wp_color_management_surface_v1 wp_color_management_surface_v1
 * @section page_iface_wp_color_management_surface_v1_desc Description
 *
 * A wp_color_management_surface_v1 allows the client to set the color
 * space and HDR properties of a surface.
 *
 * If the wl_surface associated with the wp_color_management_surface_v1 is
 * destroyed, the wp_color_management_surface_v1 object becomes inert.
 * @section page_iface_wp_color_management_surface_v1_api API
 * See @ref iface_wp_color_management_surface_v1.
 */
/**
 * @defgroup iface_wp_color_management_surface_v1 The wp_color_management_surface_v1 interface
 *
 * A wp_color_management_surface_v1 allows the client to set the color
 * space and HDR properties of a surface.
 *
 * If the wl_surface associated with the wp_color_management_surface_v1 is
 * destroyed, the wp_color_management_surface_v1 object becomes inert.
 */
extern const struct wl_interface wp_color_management_surface_v1_interface;
#endif
#ifndef WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_INTERFACE
#define WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_INTERFACE
/**
 * @page page_iface_wp_image_description_creator_icc_v1 wp_image_description_creator_icc_v1
 * @section page_iface_wp_image_description_creator_icc_v1_desc Description
 *
 * This type of object is used for collecting all the information required
 * to create a wp_image_description_v1 object from an ICC file. A complete
 * set of required parameters consists of these properties:
 * - ICC file
 *
 * Each required property must be set exactly once if the client is to create
 * an image description. The set requests verify that a property was not
 * already set. The create request verifies that all required properties are
 * set. There may be several alternative requests for setting each property,
 * and in that case the client must choose one of them.
 *
 * Once all properties have been set, the create request can be used to
 * create the image description object. Finally, the params object should
 * be destroyed.
 * @section page_iface_wp_image_description_creator_icc_v1_api API
 * See @ref iface_wp_image_description_creator_icc_v1.
 */
/**
 * @defgroup iface_wp_image_description_creator_icc_v1 The wp_image_description_creator_icc_v1 interface
 *
 * This type of object is used for collecting all the information required
 * to create a wp_image_description_v1 object from an ICC file. A complete
 * set of required parameters consists of these properties:
 * - ICC file
 *
 * Each required property must be set exactly once if the client is to create
 * an image description. The set requests verify that a property was not
 * already set. The create request verifies that all required properties are
 * set. There may be several alternative requests for setting each property,
 * and in that case the client must choose one of them.
 *
 * Once all properties have been set, the create request can be used to
 * create the image description object. Finally, the params object should
 * be destroyed.
 */
extern const struct wl_interface wp_image_description_creator_icc_v1_interface;
#endif
#ifndef WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_INTERFACE
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_INTERFACE
/**
 * @page page_iface_wp_image_description_creator_params_v1 wp_image_description_creator_params_v1
 * @section page_iface_wp_image_description_creator_params_v1_desc Description
 *
 * This type of object is used for collecting all the parameters required
 * to create a wp_image_description_v1 object. A complete set of required
 * parameters consists of these properties:
 * - transfer characteristic function (tf)
 * - chromaticities of primaries and white point (primary color volume)
 *
 * The following properties are optional and have a well-defined default
 * if not explicitly set:
 * - mastering display primaries and white point (target color volume)
 * - mastering luminance range
 * - maximum content light level
 * - maximum frame-average light level
 *
 * Each required property must be set exactly once if the client is to create
 * an image description. The set requests verify that a property was not
 * already set. The create request verifies that all required properties are
 * set. There may be several alternative requests for setting each property,
 * and in that case the client must choose one of them.
 *
 * Once all properties have been set, the create request can be used to
 * create the image description object. Finally, the params object should
 * be destroyed.
 * @section page_iface_wp_image_description_creator_params_v1_api API
 * See @ref iface_wp_image_description_creator_params_v1.
 */
/**
 * @defgroup iface_wp_image_description_creator_params_v1 The wp_image_description_creator_params_v1 interface
 *
 * This type of object is used for collecting all the parameters required
 * to create a wp_image_description_v1 object. A complete set of required
 * parameters consists of these properties:
 * - transfer characteristic function (tf)
 * - chromaticities of primaries and white point (primary color volume)
 *
 * The following properties are optional and have a well-defined default
 * if not explicitly set:
 * - mastering display primaries and white point (target color volume)
 * - mastering luminance range
 * - maximum content light level
 * - maximum frame-average light level
 *
 * Each required property must be set exactly once if the client is to create
 * an image description. The set requests verify that a property was not
 * already set. The create request verifies that all required properties are
 * set. There may be several alternative requests for setting each property,
 * and in that case the client must choose one of them.
 *
 * Once all properties have been set, the create request can be used to
 * create the image description object. Finally, the params object should
 * be destroyed.
 */
extern const struct wl_interface wp_image_description_creator_params_v1_interface;
#endif
#ifndef WP_IMAGE_DESCRIPTION_V1_INTERFACE
#define WP_IMAGE_DESCRIPTION_V1_INTERFACE
/**
 * @page page_iface_wp_image_description_v1 wp_image_description_v1
 * @section page_iface_wp_image_description_v1_desc Description
 *
 * An image description carries information about the color encoding used
 * on a surface when attached to a wl_surface via
 * wp_color_management_surface_v1.set_image_description. A compositor can
 * use this information to decode pixel values into colorimetrically
 * meaningful quantities.
 *
 * Note, that the wp_image_description_v1 object is not ready to be used
 * immediately after creation. The object eventually delivers either the
 * 'ready' or the 'failed' event, specified in all requests creating it. The
 * object is deemed "ready" after receiving the 'ready' event.
 *
 * An object which is not ready is illegal to use, it can only be destroyed.
 * Any other request in this interface shall result in the 'not_ready'
 * protocol error. Attempts to use an object which is not ready through other
 * interfaces shall raise protocol errors defined there.
 *
 * Once created and regardless of how it was created, a wp_image_description_v1
 * object always refers to one fixed image description. It cannot change
 * after creation.
 * @section page_iface_wp_image_description_v1_api API
 * See @ref iface_wp_image_description_v1.
 */
/**
 * @defgroup iface_wp_image_description_v1 The wp_image_description_v1 interface
 *
 * An image description carries information about the color encoding used
 * on a surface when attached to a wl_surface via
 * wp_color_management_surface_v1.set_image_description. A compositor can
 * use this information to decode pixel values into colorimetrically
 * meaningful quantities.
 *
 * Note, that the wp_image_description_v1 object is not ready to be used
 * immediately after creation. The object eventually delivers either the
 * 'ready' or the 'failed' event, specified in all requests creating it. The
 * object is deemed "ready" after receiving the 'ready' event.
 *
 * An object which is not ready is illegal to use, it can only be destroyed.
 * Any other request in this interface shall result in the 'not_ready'
 * protocol error. Attempts to use an object which is not ready through other
 * interfaces shall raise protocol errors defined there.
 *
 * Once created and regardless of how it was created, a wp_image_description_v1
 * object always refers to one fixed image description. It cannot change
 * after creation.
 */
extern const struct wl_interface wp_image_description_v1_interface;
#endif

#ifndef WP_COLOR_MANAGER_V1_ERROR_ENUM
#define WP_COLOR_MANAGER_V1_ERROR_ENUM
enum wp_color_manager_v1_error {
	/**
	 * request not supported
	 */
	WP_COLOR_MANAGER_V1_ERROR_UNSUPPORTED_FEATURE = 0,
};
#endif /* WP_COLOR_MANAGER_V1_ERROR_ENUM */

#ifndef WP_COLOR_MANAGER_V1_RENDER_INTENT_ENUM
#define WP_COLOR_MANAGER_V1_RENDER_INTENT_ENUM
/**
 * @ingroup iface_wp_color_manager_v1
 * rendering intents
 *
 * See the ICC.1:2022 specification from the International Color Consortium
 * for more details about rendering intents.
 *
 * The principles of ICC defined rendering intents apply with all types
 * of image descriptions, not only those with ICC file profiles.
 *
 * Compositors must support the perceptual rendering intent. Other
 * rendering intents are optional.
 */
enum wp_color_manager_v1_render_intent {
	/**
	 * perceptual
	 */
	WP_COLOR_MANAGER_V1_RENDER_INTENT_PERCEPTUAL = 0,
	/**
	 * media-relative colorimetric
	 */
	WP_COLOR_MANAGER_V1_RENDER_INTENT_RELATIVE = 1,
	/**
	 * saturation
	 */
	WP_COLOR_MANAGER_V1_RENDER_INTENT_SATURATION = 2,
	/**
	 * ICC-absolute colorimetric
	 */
	WP_COLOR_MANAGER_V1_RENDER_INTENT_ABSOLUTE = 3,
	/**
	 * media-relative colorimetric + black point compensation
	 */
	WP_COLOR_MANAGER_V1_RENDER_INTENT_RELATIVE_BPC = 4,
};
#endif /* WP_COLOR_MANAGER_V1_RENDER_INTENT_ENUM */

#ifndef WP_COLOR_MANAGER_V1_FEATURE_ENUM
#define WP_COLOR_MANAGER_V1_FEATURE_ENUM
/**
 * @ingroup iface_wp_color_manager_v1
 * compositor supported features
 */
enum wp_color_manager_v1_feature {
	/**
	 * new_icc_creator request
	 */
	WP_COLOR_MANAGER_V1_FEATURE_ICC_V2_V4 = 0,
	/**
	 * new_parametric_creator request
	 */
	WP_COLOR_MANAGER_V1_FEATURE_PARAMETRIC = 1,
	/**
	 * parametric set_primaries request
	 */
	WP_COLOR_MANAGER_V1_FEATURE_SET_PRIMARIES = 2,
	/**
	 * parametric set_tf_power request
	 */
	WP_COLOR_MANAGER_V1_FEATURE_SET_TF_POWER = 3,
	/**
	 * parametric set_mastering_display_primaries request
	 *
	 * The compositor supports set_mastering_display_primaries
	 * request with a target color volume fully contained inside the
	 * primary color volume.
	 */
	WP_COLOR_MANAGER_V1_FEATURE_SET_MASTERING_DISPLAY_PRIMARIES = 4,
	/**
	 * parametric target exceeds primary color volume
	 *
	 * The compositor additionally supports target color volumes that
	 * extend outside of the primary color volume.
	 *
	 * This can only be advertised if feature
	 * set_mastering_display_primaries is supported as well.
	 */
	WP_COLOR_MANAGER_V1_FEATURE_EXTENDED_TARGET_VOLUME = 5,
};
#endif /* WP_COLOR_MANAGER_V1_FEATURE_ENUM */

/**
 * @ingroup iface_wp_color_manager_v1
 * @struct wp_color_manager_v1_listener
 */
struct wp_color_manager_v1_listener {
	/**
	 * supported rendering intent
	 *
	 * When this object is created, it shall immediately send this
	 * event once for each rendering intent the compositor supports.
	 * @param render_intent rendering intent
	 */
	void (*supported_intent)(void *data,
				 struct wp_color_manager_v1 *wp_color_manager_v1,
				 uint32_t render_intent);
	/**
	 * supported features
	 *
	 * When this object is created, it shall immediately send this
	 * event once for each compositor supported feature listed in the
	 * enumeration.
	 * @param feature supported feature
	 */
	void (*supported_feature)(void *data,
				  struct wp_color_manager_v1 *wp_color_manager_v1,
				  uint32_t feature);
	/**
	 * supported transfer characteristic code point
	 *
	 * When this object is created, it shall immediately send this
	 * event once for each H.273 TransferCharacteristics code point the
	 * compositor supports with the parametric image description
	 * creator.
	 * @param tf_code TransferCharacteristics code point
	 */
	void (*supported_tf_cicp)(void *data,
				  struct wp_color_manager_v1 *wp_color_manager_v1,
				  uint32_t tf_code);
	/**
	 * supported primaries code point
	 *
	 * When this object is created, it shall immediately send this
	 * event once for each H.273 ColourPrimaries code point the
	 * compositor supports with the parametric image description
	 * creator.
	 * @param primaries_code ColourPrimaries code point
	 */
	void (*supported_primaries_cicp)(void *data,
					 struct wp_color_manager_v1 *wp_color_manager_v1,
					 uint32_t primaries_code);
};

/**
 * @ingroup iface_wp_color_manager_v1
 */
static inline int
wp_color_manager_v1_add_listener(struct wp_color_manager_v1 *wp_color_manager_v1,
				 const struct wp_color_manager_v1_listener *listener, void *data)
{
	return wl_proxy_add_listener((struct wl_proxy *) wp_color_manager_v1,
				     (void (**)(void)) listener, data);
}

#define WP_COLOR_MANAGER_V1_DESTROY 0
#define WP_COLOR_MANAGER_V1_GET_COLOR_MANAGEMENT_OUTPUT 1
#define WP_COLOR_MANAGER_V1_GET_COLOR_MANAGEMENT_SURFACE 2
#define WP_COLOR_MANAGER_V1_NEW_ICC_CREATOR 3
#define WP_COLOR_MANAGER_V1_NEW_PARAMETRIC_CREATOR 4

/**
 * @ingroup iface_wp_color_manager_v1
 */
#define WP_COLOR_MANAGER_V1_SUPPORTED_INTENT_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_manager_v1
 */
#define WP_COLOR_MANAGER_V1_SUPPORTED_FEATURE_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_manager_v1
 */
#define WP_COLOR_MANAGER_V1_SUPPORTED_TF_CICP_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_manager_v1
 */
#define WP_COLOR_MANAGER_V1_SUPPORTED_PRIMARIES_CICP_SINCE_VERSION 1

/**
 * @ingroup iface_wp_color_manager_v1
 */
#define WP_COLOR_MANAGER_V1_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_manager_v1
 */
#define WP_COLOR_MANAGER_V1_GET_COLOR_MANAGEMENT_OUTPUT_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_manager_v1
 */
#define WP_COLOR_MANAGER_V1_GET_COLOR_MANAGEMENT_SURFACE_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_manager_v1
 */
#define WP_COLOR_MANAGER_V1_NEW_ICC_CREATOR_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_manager_v1
 */
#define WP_COLOR_MANAGER_V1_NEW_PARAMETRIC_CREATOR_SINCE_VERSION 1

/** @ingroup iface_wp_color_manager_v1 */
static inline void
wp_color_manager_v1_set_user_data(struct wp_color_manager_v1 *wp_color_manager_v1, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) wp_color_manager_v1, user_data);
}

/** @ingroup iface_wp_color_manager_v1 */
static inline void *
wp_color_manager_v1_get_user_data(struct wp_color_manager_v1 *wp_color_manager_v1)
{
	return wl_proxy_get_user_data((struct wl_proxy *) wp_color_manager_v1);
}

static inline uint32_t
wp_color_manager_v1_get_version(struct wp_color_manager_v1 *wp_color_manager_v1)
{
	return wl_proxy_get_version((struct wl_proxy *) wp_color_manager_v1);
}

/**
 * @ingroup iface_wp_color_manager_v1
 *
 * Destroy the wp_color_manager_v1 object. This does not affect any other
 * objects in any way.
 */
static inline void
wp_color_manager_v1_destroy(struct wp_color_manager_v1 *wp_color_manager_v1)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_color_manager_v1,
			 WP_COLOR_MANAGER_V1_DESTROY, NULL, wl_proxy_get_version((struct wl_proxy *) wp_color_manager_v1), WL_MARSHAL_FLAG_DESTROY);
}

/**
 * @ingroup iface_wp_color_manager_v1
 *
 * This creates a new wp_color_management_output_v1 object for the
 * given wl_output.
 *
 * See the wp_color_management_output_v1 interface for more details.
 */
static inline struct wp_color_management_output_v1 *
wp_color_manager_v1_get_color_management_output(struct wp_color_manager_v1 *wp_color_manager_v1, struct wl_output *output)
{
	struct wl_proxy *id;

	id = wl_proxy_marshal_flags((struct wl_proxy *) wp_color_manager_v1,
			 WP_COLOR_MANAGER_V1_GET_COLOR_MANAGEMENT_OUTPUT, &wp_color_management_output_v1_interface, wl_proxy_get_version((struct wl_proxy *) wp_color_manager_v1), 0, NULL, output);

	return (struct wp_color_management_output_v1 *) id;
}

/**
 * @ingroup iface_wp_color_manager_v1
 *
 * This creates a new color wp_color_management_surface_v1 object for the
 * given wl_surface.
 *
 * See the wp_color_management_surface_v1 interface for more details.
 */
static inline struct wp_color_management_surface_v1 *
wp_color_manager_v1_get_color_management_surface(struct wp_color_manager_v1 *wp_color_manager_v1, struct wl_surface *surface)
{
	struct wl_proxy *id;

	id = wl_proxy_marshal_flags((struct wl_proxy *) wp_color_manager_v1,
			 WP_COLOR_MANAGER_V1_GET_COLOR_MANAGEMENT_SURFACE, &wp_color_management_surface_v1_interface, wl_proxy_get_version((struct wl_proxy *) wp_color_manager_v1), 0, NULL, surface);

	return (struct wp_color_management_surface_v1 *) id;
}

/**
 * @ingroup iface_wp_color_manager_v1
 *
 * Makes a new ICC-based image description creator object with all
 * properties initially unset. The client can then use the object's
 * interface to define all the required properties for an image description
 * and finally create a wp_image_description_v1 object.
 *
 * This request can be used when the compositor advertises
 * wp_color_manager_v1.feature.icc_v2_v4.
 * Otherwise this request raises the protocol error unsupported_feature.
 */
static inline struct wp_image_description_creator_icc_v1 *
wp_color_manager_v1_new_icc_creator(struct wp_color_manager_v1 *wp_color_manager_v1)
{
	struct wl_proxy *obj;

	obj = wl_proxy_marshal_flags((struct wl_proxy *) wp_color_manager_v1,
			 WP_COLOR_MANAGER_V1_NEW_ICC_CREATOR, &wp_image_description_creator_icc_v1_interface, wl_proxy_get_version((struct wl_proxy *) wp_color_manager_v1), 0, NULL);

	return (struct wp_image_description_creator_icc_v1 *) obj;
}

/**
 * @ingroup iface_wp_color_manager_v1
 *
 * Makes a new parametric image description creator object with all
 * properties initially unset. The client can then use the object's
 * interface to define all the required properties for an image description
 * and finally create a wp_image_description_v1 object.
 *
 * This request can be used when the compositor advertises
 * wp_color_manager_v1.feature.parametric.
 * Otherwise this request raises the protocol error unsupported_feature.
 */
static inline struct wp_image_description_creator_params_v1 *
wp_color_manager_v1_new_parametric_creator(struct wp_color_manager_v1 *wp_color_manager_v1)
{
	struct wl_proxy *obj;

	obj = wl_proxy_marshal_flags((struct wl_proxy *) wp_color_manager_v1,
			 WP_COLOR_MANAGER_V1_NEW_PARAMETRIC_CREATOR, &wp_image_description_creator_params_v1_interface, wl_proxy_get_version((struct wl_proxy *) wp_color_manager_v1), 0, NULL);

	return (struct wp_image_description_creator_params_v1 *) obj;
}

/**
 * @ingroup iface_wp_color_management_output_v1
 * @struct wp_color_management_output_v1_listener
 */
struct wp_color_management_output_v1_listener {
	/**
	 * image description changed
	 *
	 * This event is sent whenever the image description of the
	 * output changed, followed by one wl_output.done event common to
	 * output events across all extensions.
	 *
	 * This is not an initial event.
	 *
	 * If the client wants to use the updated image description, it
	 * needs to do get_image_description again, because image
	 * description objects are immutable.
	 */
	void (*image_description_changed)(void *data,
					  struct wp_color_management_output_v1 *wp_color_management_output_v1);
};

/**
 * @ingroup iface_wp_color_management_output_v1
 */
static inline int
wp_color_management_output_v1_add_listener(struct wp_color_management_output_v1 *wp_color_management_output_v1,
					   const struct wp_color_management_output_v1_listener *listener, void *data)
{
	return wl_proxy_add_listener((struct wl_proxy *) wp_color_management_output_v1,
				     (void (**)(void)) listener, data);
}

#define WP_COLOR_MANAGEMENT_OUTPUT_V1_DESTROY 0
#define WP_COLOR_MANAGEMENT_OUTPUT_V1_GET_IMAGE_DESCRIPTION 1

/**
 * @ingroup iface_wp_color_management_output_v1
 */
#define WP_COLOR_MANAGEMENT_OUTPUT_V1_IMAGE_DESCRIPTION_CHANGED_SINCE_VERSION 1

/**
 * @ingroup iface_wp_color_management_output_v1
 */
#define WP_COLOR_MANAGEMENT_OUTPUT_V1_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_management_output_v1
 */
#define WP_COLOR_MANAGEMENT_OUTPUT_V1_GET_IMAGE_DESCRIPTION_SINCE_VERSION 1

/** @ingroup iface_wp_color_management_output_v1 */
static inline void
wp_color_management_output_v1_set_user_data(struct wp_color_management_output_v1 *wp_color_management_output_v1, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) wp_color_management_output_v1, user_data);
}

/** @ingroup iface_wp_color_management_output_v1 */
static inline void *
wp_color_management_output_v1_get_user_data(struct wp_color_management_output_v1 *wp_color_management_output_v1)
{
	return wl_proxy_get_user_data((struct wl_proxy *) wp_color_management_output_v1);
}

static inline uint32_t
wp_color_management_output_v1_get_version(struct wp_color_management_output_v1 *wp_color_management_output_v1)
{
	return wl_proxy_get_version((struct wl_proxy *) wp_color_management_output_v1);
}

/**
 * @ingroup iface_wp_color_management_output_v1
 *
 * Destroy the color wp_color_management_output_v1 object. This does not
 * affect any remaining protocol objects.
 */
static inline void
wp_color_management_output_v1_destroy(struct wp_color_management_output_v1 *wp_color_management_output_v1)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_color_management_output_v1,
			 WP_COLOR_MANAGEMENT_OUTPUT_V1_DESTROY, NULL, wl_proxy_get_version((struct wl_proxy *) wp_color_management_output_v1), WL_MARSHAL_FLAG_DESTROY);
}

/**
 * @ingroup iface_wp_color_management_output_v1
 *
 * This creates a new wp_image_description_v1 object for the current image description
 * of the output. There always is exactly one image description active for an
 * output so the client should destroy the image description created by earlier
 * invocations of this request. This request is usually sent as a reaction
 * to the image_description_changed event or when creating a
 * wp_color_management_output_v1 object.
 *
 * The created wp_image_description_v1 object preserves the image description
 * of the output from the time the object was created.
 *
 * The resulting image description object allows get_information request.
 *
 * If the interface version is inadequate for the output's image
 * description, meaning that the client does not support all the
 * events needed to deliver the crucial information, the resulting image
 * description object shall immediately deliver the
 * wp_image_description_v1.failed event with the low_version cause,
 * otherwise the object shall immediately deliver the ready event.
 */
static inline struct wp_image_description_v1 *
wp_color_management_output_v1_get_image_description(struct wp_color_management_output_v1 *wp_color_management_output_v1)
{
	struct wl_proxy *image_description;

	image_description = wl_proxy_marshal_flags((struct wl_proxy *) wp_color_management_output_v1,
			 WP_COLOR_MANAGEMENT_OUTPUT_V1_GET_IMAGE_DESCRIPTION, &wp_image_description_v1_interface, wl_proxy_get_version((struct wl_proxy *) wp_color_management_output_v1), 0, NULL);

	return (struct wp_image_description_v1 *) image_description;
}

#ifndef WP_COLOR_MANAGEMENT_SURFACE_V1_ERROR_ENUM
#define WP_COLOR_MANAGEMENT_SURFACE_V1_ERROR_ENUM
/**
 * @ingroup iface_wp_color_management_surface_v1
 * protocol errors
 */
enum wp_color_management_surface_v1_error {
	/**
	 * unsupported rendering intent
	 */
	WP_COLOR_MANAGEMENT_SURFACE_V1_ERROR_RENDER_INTENT = 1,
};
#endif /* WP_COLOR_MANAGEMENT_SURFACE_V1_ERROR_ENUM */

/**
 * @ingroup iface_wp_color_management_surface_v1
 * @struct wp_color_management_surface_v1_listener
 */
struct wp_color_management_surface_v1_listener {
	/**
	 * compositor's preferred image description for the surface
	 *
	 * The preferred image description is the one which likely has
	 * the most performance and/or quality benefits for the compositor
	 * if used by the client for its wl_surface contents. This event is
	 * sent whenever the compositor changes the wl_surface's preferred
	 * image description.
	 *
	 * This is not an initial event.
	 *
	 * This event is merely a notification. When the client wants to
	 * know what the preferred image description is, it shall use the
	 * get_preferred request.
	 *
	 * The preferred image description is not automatically used for
	 * anything. It is only a hint, and clients may set any valid image
	 * description with set_image_description but there might be
	 * performance and color accuracy improvements by providing the
	 * wl_surface contents in the preferred image description.
	 * Therefore clients that can, should render according to the
	 * preferred image description
	 */
	void (*preferred_changed)(void *data,
				  struct wp_color_management_surface_v1 *wp_color_management_surface_v1);
};

/**
 * @ingroup iface_wp_color_management_surface_v1
 */
static inline int
wp_color_management_surface_v1_add_listener(struct wp_color_management_surface_v1 *wp_color_management_surface_v1,
					    const struct wp_color_management_surface_v1_listener *listener, void *data)
{
	return wl_proxy_add_listener((struct wl_proxy *) wp_color_management_surface_v1,
				     (void (**)(void)) listener, data);
}

#define WP_COLOR_MANAGEMENT_SURFACE_V1_DESTROY 0
#define WP_COLOR_MANAGEMENT_SURFACE_V1_SET_IMAGE_DESCRIPTION 1
#define WP_COLOR_MANAGEMENT_SURFACE_V1_SET_DEFAULT_IMAGE_DESCRIPTION 2
#define WP_COLOR_MANAGEMENT_SURFACE_V1_GET_PREFERRED 3

/**
 * @ingroup iface_wp_color_management_surface_v1
 */
#define WP_COLOR_MANAGEMENT_SURFACE_V1_PREFERRED_CHANGED_SINCE_VERSION 1

/**
 * @ingroup iface_wp_color_management_surface_v1
 */
#define WP_COLOR_MANAGEMENT_SURFACE_V1_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_management_surface_v1
 */
#define WP_COLOR_MANAGEMENT_SURFACE_V1_SET_IMAGE_DESCRIPTION_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_management_surface_v1
 */
#define WP_COLOR_MANAGEMENT_SURFACE_V1_SET_DEFAULT_IMAGE_DESCRIPTION_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_management_surface_v1
 */
#define WP_COLOR_MANAGEMENT_SURFACE_V1_GET_PREFERRED_SINCE_VERSION 1

/** @ingroup iface_wp_color_management_surface_v1 */
static inline void
wp_color_management_surface_v1_set_user_data(struct wp_color_management_surface_v1 *wp_color_management_surface_v1, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) wp_color_management_surface_v1, user_data);
}

/** @ingroup iface_wp_color_management_surface_v1 */
static inline void *
wp_color_management_surface_v1_get_user_data(struct wp_color_management_surface_v1 *wp_color_management_surface_v1)
{
	return wl_proxy_get_user_data((struct wl_proxy *) wp_color_management_surface_v1);
}

static inline uint32_t
wp_color_management_surface_v1_get_version(struct wp_color_management_surface_v1 *wp_color_management_surface_v1)
{
	return wl_proxy_get_version((struct wl_proxy *) wp_color_management_surface_v1);
}

/**
 * @ingroup iface_wp_color_management_surface_v1
 *
 * Destroy the wp_color_management_surface_v1 object.
 *
 * When the last wp_color_management_surface_v1 object for a wl_surface
 * is destroyed, it does the same as set_default_image_description.
 */
static inline void
wp_color_management_surface_v1_destroy(struct wp_color_management_surface_v1 *wp_color_management_surface_v1)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_color_management_surface_v1,
			 WP_COLOR_MANAGEMENT_SURFACE_V1_DESTROY, NULL, wl_proxy_get_version((struct wl_proxy *) wp_color_management_surface_v1), WL_MARSHAL_FLAG_DESTROY);
}

/**
 * @ingroup iface_wp_color_management_surface_v1
 *
 * Set the image description of the underlying surface. The image
 * description and rendering intent are double-buffered state, see
 * wl_surface.commit.
 *
 * It is the client's responsibility to understand the image description
 * it sets on a surface, and to provide content that matches that image
 * description.
 *
 * A rendering intent provides the client's preference on how content
 * colors should be mapped to each output. The render_intent value must
 * be one advertised by the compositor with
 * wp_color_manager_v1.render_intent event, otherwise the protocol error
 * render_intent is raised.
 *
 * By default, a surface does not have an associated image description
 * nor a rendering intent. The handling of color on such surfaces is
 * compositor implementation defined.
 */
static inline void
wp_color_management_surface_v1_set_image_description(struct wp_color_management_surface_v1 *wp_color_management_surface_v1, struct wp_image_description_v1 *image_description, uint32_t render_intent)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_color_management_surface_v1,
			 WP_COLOR_MANAGEMENT_SURFACE_V1_SET_IMAGE_DESCRIPTION, NULL, wl_proxy_get_version((struct wl_proxy *) wp_color_management_surface_v1), 0, image_description, render_intent);
}

/**
 * @ingroup iface_wp_color_management_surface_v1
 *
 * This request sets the surface image description to the defaults, see
 * set_image_description. This is double-buffered state, see
 * wl_surface.commit.
 */
static inline void
wp_color_management_surface_v1_set_default_image_description(struct wp_color_management_surface_v1 *wp_color_management_surface_v1)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_color_management_surface_v1,
			 WP_COLOR_MANAGEMENT_SURFACE_V1_SET_DEFAULT_IMAGE_DESCRIPTION, NULL, wl_proxy_get_version((struct wl_proxy *) wp_color_management_surface_v1), 0);
}

/**
 * @ingroup iface_wp_color_management_surface_v1
 *
 * This creates a new wp_image_description_v1 object for the currently
 * preferred image description for the wl_surface. The client should
 * stop using and destroy the image descriptions created by earlier
 * invocations of this request for the associated wl_surface.
 * This request is usually sent as a reaction to the preferred_changed
 * event or when creating a wp_color_management_surface_v1 object if
 * the client is capable of adapting to image descriptions.
 *
 * The created wp_image_description_v1 object preserves the preferred image
 * description of the wl_surface from the time the object was created.
 *
 * The resulting image description object allows get_information request.
 *
 * If the interface version is inadequate for the preferred image
 * description, meaning that the client does not support all the
 * events needed to deliver the crucial information, the resulting image
 * description object shall immediately deliver the
 * wp_image_description_v1.failed event with the low_version cause,
 * otherwise the object shall immediately deliver the ready event.
 */
static inline struct wp_image_description_v1 *
wp_color_management_surface_v1_get_preferred(struct wp_color_management_surface_v1 *wp_color_management_surface_v1)
{
	struct wl_proxy *image_description;

	image_description = wl_proxy_marshal_flags((struct wl_proxy *) wp_color_management_surface_v1,
			 WP_COLOR_MANAGEMENT_SURFACE_V1_GET_PREFERRED, &wp_image_description_v1_interface, wl_proxy_get_version((struct wl_proxy *) wp_color_management_surface_v1), 0, NULL);

	return (struct wp_image_description_v1 *) image_description;
}

#ifndef WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_ERROR_ENUM
#define WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_ERROR_ENUM
/**
 * @ingroup iface_wp_image_description_creator_icc_v1
 * protocol errors
 */
enum wp_image_description_creator_icc_v1_error {
	/**
	 * incomplete parameter set
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_ERROR_INCOMPLETE_SET = 0,
	/**
	 * invalid combination of parameters
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_ERROR_INCONSISTENT_SET = 1,
	/**
	 * create request already done
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_ERROR_ALREADY_USED = 2,
	/**
	 * property already set
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_ERROR_ALREADY_SET = 3,
	/**
	 * fd not seekable and readable
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_ERROR_BAD_FD = 4,
	/**
	 * no or too much data
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_ERROR_BAD_SIZE = 5,
};
#endif /* WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_ERROR_ENUM */

#define WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_DESTROY 0
#define WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_CREATE 1
#define WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_SET_ICC_FILE 2


/**
 * @ingroup iface_wp_image_description_creator_icc_v1
 */
#define WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_creator_icc_v1
 */
#define WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_CREATE_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_creator_icc_v1
 */
#define WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_SET_ICC_FILE_SINCE_VERSION 1

/** @ingroup iface_wp_image_description_creator_icc_v1 */
static inline void
wp_image_description_creator_icc_v1_set_user_data(struct wp_image_description_creator_icc_v1 *wp_image_description_creator_icc_v1, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) wp_image_description_creator_icc_v1, user_data);
}

/** @ingroup iface_wp_image_description_creator_icc_v1 */
static inline void *
wp_image_description_creator_icc_v1_get_user_data(struct wp_image_description_creator_icc_v1 *wp_image_description_creator_icc_v1)
{
	return wl_proxy_get_user_data((struct wl_proxy *) wp_image_description_creator_icc_v1);
}

static inline uint32_t
wp_image_description_creator_icc_v1_get_version(struct wp_image_description_creator_icc_v1 *wp_image_description_creator_icc_v1)
{
	return wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_icc_v1);
}

/**
 * @ingroup iface_wp_image_description_creator_icc_v1
 *
 * Destroys this object. No other object is affected.
 */
static inline void
wp_image_description_creator_icc_v1_destroy(struct wp_image_description_creator_icc_v1 *wp_image_description_creator_icc_v1)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_creator_icc_v1,
			 WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_DESTROY, NULL, wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_icc_v1), WL_MARSHAL_FLAG_DESTROY);
}

/**
 * @ingroup iface_wp_image_description_creator_icc_v1
 *
 * Create an image description object based on the ICC information
 * previously set on this object. A compositor must parse the ICC data in
 * some undefined but finite amount of time.
 *
 * The completeness of the parameter set is verified. If the set is not
 * complete, the protocol error incomplete_set is raised. For the
 * definition of a complete set, see the description of this interface.
 *
 * If the particular combination of the information is not supported
 * by the compositor, the resulting image description object shall
 * immediately deliver the wp_image_description_v1.failed event with the
 * 'unsupported' cause. If a valid image description was created from the
 * information, the wp_image_description_v1.ready event will eventually
 * be sent instead.
 *
 * This request can be issued at most once during the lifetime of the
 * wp_image_description_creator_icc_v1 object, after which the only
 * legal request is destroy. Otherwise the protocol error already_used
 * is raised.
 *
 * A client should destroy this object immediately after this request.
 *
 * The resulting image description object does not allow get_information
 * request.
 */
static inline struct wp_image_description_v1 *
wp_image_description_creator_icc_v1_create(struct wp_image_description_creator_icc_v1 *wp_image_description_creator_icc_v1)
{
	struct wl_proxy *image_description;

	image_description = wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_creator_icc_v1,
			 WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_CREATE, &wp_image_description_v1_interface, wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_icc_v1), 0, NULL);

	return (struct wp_image_description_v1 *) image_description;
}

/**
 * @ingroup iface_wp_image_description_creator_icc_v1
 *
 * Sets the ICC profile file to be used as the basis of the image
 * description.
 *
 * The data shall be found through the given fd at the given offset,
 * having the given length. The fd must seekable and readable. Violating
 * these requirements raises the bad_fd protocol error.
 *
 * The maximum size of the ICC profile is 4 MB. If length is greater
 * than that or zero, the protocol error bad_size is raised.
 *
 * A compositor may read the file at any time starting from this request
 * and only until whichever happens first:
 * - If create request was issued, the wp_image_description_v1 object
 * delivers either failed or ready event; or
 * - if create request was not issued, this
 * wp_image_description_creator_icc_v1 object is destroyed.
 *
 * A compositor shall not modify the contents of the file, and the fd may
 * be sealed for writes and size changes. The client must ensure to its
 * best ability that the data does not change while the compositor is
 * reading it.
 *
 * The data must represent a valid ICC profile.
 * The ICC profile version must be 2 or 4, it must be a 3 channel profile
 * and the class must be 'display'.
 * Violating these requirements will not result in a protocol error but
 * will eventually send the wp_image_description_v1.failed event on the
 * created wp_image_description_v1 with the 'unsupported' cause.
 *
 * See the International Color Consortium specification ICC.1:2022 for more
 * details about ICC profiles.
 */
static inline void
wp_image_description_creator_icc_v1_set_icc_file(struct wp_image_description_creator_icc_v1 *wp_image_description_creator_icc_v1, int32_t icc_profile, uint32_t offset, uint32_t length)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_creator_icc_v1,
			 WP_IMAGE_DESCRIPTION_CREATOR_ICC_V1_SET_ICC_FILE, NULL, wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_icc_v1), 0, icc_profile, offset, length);
}

#ifndef WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_ERROR_ENUM
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_ERROR_ENUM
/**
 * @ingroup iface_wp_image_description_creator_params_v1
 * protocol errors
 */
enum wp_image_description_creator_params_v1_error {
	/**
	 * incomplete parameter set
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_ERROR_INCOMPLETE_SET = 0,
	/**
	 * invalid combination of parameters
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_ERROR_INCONSISTENT_SET = 1,
	/**
	 * create request already done
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_ERROR_ALREADY_USED = 2,
	/**
	 * property already set
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_ERROR_ALREADY_SET = 3,
	/**
	 * invalid transfer characteristic
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_ERROR_INVALID_TF = 4,
	/**
	 * invalid primaries or white point
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_ERROR_INVALID_PRIMARIES = 5,
	/**
	 * invalid luminance value or range
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_ERROR_INVALID_LUMINANCE = 6,
	/**
	 * invalid mastering information
	 */
	WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_ERROR_INVALID_MASTERING = 7,
};
#endif /* WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_ERROR_ENUM */

#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_DESTROY 0
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_CREATE 1
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_TF_CICP 2
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_TF_POWER 3
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_PRIMARIES_CICP 4
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_PRIMARIES 5
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_MASTERING_DISPLAY_PRIMARIES 6
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_MASTERING_LUMINANCE 7
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_MAX_CLL 8
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_MAX_FALL 9


/**
 * @ingroup iface_wp_image_description_creator_params_v1
 */
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_creator_params_v1
 */
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_CREATE_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_creator_params_v1
 */
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_TF_CICP_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_creator_params_v1
 */
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_TF_POWER_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_creator_params_v1
 */
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_PRIMARIES_CICP_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_creator_params_v1
 */
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_PRIMARIES_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_creator_params_v1
 */
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_MASTERING_DISPLAY_PRIMARIES_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_creator_params_v1
 */
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_MASTERING_LUMINANCE_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_creator_params_v1
 */
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_MAX_CLL_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_creator_params_v1
 */
#define WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_MAX_FALL_SINCE_VERSION 1

/** @ingroup iface_wp_image_description_creator_params_v1 */
static inline void
wp_image_description_creator_params_v1_set_user_data(struct wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) wp_image_description_creator_params_v1, user_data);
}

/** @ingroup iface_wp_image_description_creator_params_v1 */
static inline void *
wp_image_description_creator_params_v1_get_user_data(struct wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1)
{
	return wl_proxy_get_user_data((struct wl_proxy *) wp_image_description_creator_params_v1);
}

static inline uint32_t
wp_image_description_creator_params_v1_get_version(struct wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1)
{
	return wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_params_v1);
}

/**
 * @ingroup iface_wp_image_description_creator_params_v1
 *
 * Destroys this object. No other object is affected.
 */
static inline void
wp_image_description_creator_params_v1_destroy(struct wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_creator_params_v1,
			 WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_DESTROY, NULL, wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_params_v1), WL_MARSHAL_FLAG_DESTROY);
}

/**
 * @ingroup iface_wp_image_description_creator_params_v1
 *
 * Create an image description object based on the parameters previously
 * set on this object.
 *
 * The completeness of the parameter set is verified. If the set is not
 * complete, the protocol error incomplete_set is raised. For the
 * definition of a complete set, see the description of this interface.
 *
 * If the particular combination of the parameter set is not supported
 * by the compositor, the resulting image description object shall
 * immediately deliver the wp_image_description_v1.failed event with the
 * 'unsupported' cause. If a valid image description was created from the
 * parameter set, the wp_image_description_v1.ready event will eventually
 * be sent instead.
 *
 * This request can be issued at most once during the lifetime of the
 * wp_image_description_creator_params_v1 object, after which the only
 * legal request is destroy. Otherwise the protocol error already_used
 * is raised.
 *
 * A client should destroy this object immediately after this request.
 *
 * The resulting image description object does not allow get_information
 * request.
 */
static inline struct wp_image_description_v1 *
wp_image_description_creator_params_v1_create(struct wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1)
{
	struct wl_proxy *image_description;

	image_description = wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_creator_params_v1,
			 WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_CREATE, &wp_image_description_v1_interface, wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_params_v1), 0, NULL);

	return (struct wp_image_description_v1 *) image_description;
}

/**
 * @ingroup iface_wp_image_description_creator_params_v1
 *
 * Sets the transfer characteristic using H.273 TransferCharacteristics
 * code points.
 *
 * Only code points advertised with wp_color_manager_v1
 * event supported_tf_cicp are allowed. Other values shall raise the
 * protocol error invalid_tf.
 *
 * If transfer characteristic has already been set on this object, the
 * protocol error already_set is raised.
 */
static inline void
wp_image_description_creator_params_v1_set_tf_cicp(struct wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1, uint32_t tf_code)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_creator_params_v1,
			 WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_TF_CICP, NULL, wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_params_v1), 0, tf_code);
}

/**
 * @ingroup iface_wp_image_description_creator_params_v1
 *
 * Sets the color component transfer characteristic to a power curve
 * with the given exponent. This curve represents the conversion from
 * electrical to optical pixel or color values.
 *
 * The curve exponent shall be multiplied by 10000 to get the argument
 * eexp value to carry the precision of 4 decimals.
 *
 * The curve exponent must be at least 1.0 and at most 10.0. Otherwise
 * the protocol error invalid_tf is raised.
 *
 * If transfer characteristic has already been set on this object, the
 * protocol error already_set is raised.
 *
 * This request can be used when the compositor advertises
 * wp_color_manager_v1.feature.set_tf_power. Otherwise this request raises
 * the protocol error invalid_tf.
 */
static inline void
wp_image_description_creator_params_v1_set_tf_power(struct wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1, uint32_t eexp)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_creator_params_v1,
			 WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_TF_POWER, NULL, wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_params_v1), 0, eexp);
}

/**
 * @ingroup iface_wp_image_description_creator_params_v1
 *
 * Sets the color primaries and white point using H.273 ColourPrimaries
 * code points. This describes the primary color volume which is the basis
 * for color value encoding.
 *
 * Only code points advertised with wp_color_manager_v1
 * event supported_primaries_cicp are allowed. Other values shall raise the
 * protocol error invalid_primaries.
 *
 * If primaries have already been set on this object, the protocol error
 * already_set is raised.
 */
static inline void
wp_image_description_creator_params_v1_set_primaries_cicp(struct wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1, uint32_t primaries_code)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_creator_params_v1,
			 WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_PRIMARIES_CICP, NULL, wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_params_v1), 0, primaries_code);
}

/**
 * @ingroup iface_wp_image_description_creator_params_v1
 *
 * Sets the color primaries and white point using CIE 1931 xy
 * chromaticity coordinates. This describes the primary color volume
 * which is the basis for color value encoding.
 *
 * Each coordinate value is multiplied by 10000 to get the argument
 * value to carry precision of 4 decimals.
 *
 * If primaries have already been set on this object, the protocol error
 * already_set is raised.
 *
 * This request can be used if the compositor advertises
 * wp_color_manager_v1.feature.set_primaries. Otherwise this request
 * raises the protocol error invalid_primaries.
 */
static inline void
wp_image_description_creator_params_v1_set_primaries(struct wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1, uint32_t r_x, uint32_t r_y, uint32_t g_x, uint32_t g_y, uint32_t b_x, uint32_t b_y, uint32_t w_x, uint32_t w_y)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_creator_params_v1,
			 WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_PRIMARIES, NULL, wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_params_v1), 0, r_x, r_y, g_x, g_y, b_x, b_y, w_x, w_y);
}

/**
 * @ingroup iface_wp_image_description_creator_params_v1
 *
 * Provides the color primaries and white point of the mastering display
 * using CIE 1931 xy chromaticity coordinates. This is compatible with the
 * SMPTE ST 2086 definition of HDR static metadata.
 *
 * The primaries and transfer characteristics define how an encoded pixel
 * value is converted to CIE 1931 XYZ but they do not define what
 * sub-volume of the container color volume in XYZ is meaningful for the
 * content. The mastering display primaries help defining this target color
 * volume. Compositors may use the target color volume to improve gamut
 * mapping when applicable for the chosen rendering intent.
 *
 * If mastering display primaries are not explicitly set, the target
 * color volume is assumed to be equal to the primary color volume.
 *
 * The target color volume can exceed the primary color volume to allow for
 * a greater color volume with an existing color space definition (for
 * example scRGB). It can be smaller than the primary color volume to
 * minimize gamut and tone mapping distances for big color spaces (HDR
 * metadata).
 *
 * To make use of the entire target color volume a suitable pixel format
 * has to be chosen (e.g. floating point to exceed the primary color
 * volume, or abusing limited quantization range as with xvYCC).
 *
 * Each coordinate value is multiplied by 10000 to get the argument
 * value to carry precision of 4 decimals.
 *
 * If mastering display primaries have already been set on this object,
 * the protocol error already_set is raised.
 *
 * This request can be used if the compositor advertises
 * wp_color_manager_v1.feature.set_mastering_display_primaries.
 * Otherwise this request raises the protocol error invalid_mastering.
 * The advertisement implies support only for target color
 * volumes fully contained within the primary color volume.
 *
 * If a compositor additionally supports target color volume exceeding
 * the primary color volume, it must advertise
 * wp_color_manager_v1.feature.extended_target_volume.
 * If a client uses target color volume exceeding the primary color volume
 * and the compositor does not support it, the result is implementation
 * defined. Compositors are recommended to detect this case and fail the
 * image description gracefully, but it may as well result in color
 * artifacts.
 */
static inline void
wp_image_description_creator_params_v1_set_mastering_display_primaries(struct wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1, uint32_t r_x, uint32_t r_y, uint32_t g_x, uint32_t g_y, uint32_t b_x, uint32_t b_y, uint32_t w_x, uint32_t w_y)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_creator_params_v1,
			 WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_MASTERING_DISPLAY_PRIMARIES, NULL, wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_params_v1), 0, r_x, r_y, g_x, g_y, b_x, b_y, w_x, w_y);
}

/**
 * @ingroup iface_wp_image_description_creator_params_v1
 *
 * Sets the luminance range that was used during the content mastering
 * process as the minimum and maximum absolute luminance L. This is
 * compatible with the SMPTE ST 2086 definition of HDR static metadata.
 *
 * This can only be set when set_tf_cicp is used to set the transfer
 * characteristic to Rec. ITU-R BT.2100-2 perceptual quantization system.
 * Otherwise, 'create' request shall raise inconsistent_set protocol
 * error.
 *
 * The mastering luminance range is undefined by default.
 *
 * If max L is less than or equal to min L, the protocol error
 * invalid_luminance is raised.
 *
 * Min L value is multiplied by 10000 to get the argument min_lum value
 * and carry precision of 4 decimals. Max L value is unscaled for max_lum.
 */
static inline void
wp_image_description_creator_params_v1_set_mastering_luminance(struct wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1, uint32_t min_lum, uint32_t max_lum)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_creator_params_v1,
			 WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_MASTERING_LUMINANCE, NULL, wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_params_v1), 0, min_lum, max_lum);
}

/**
 * @ingroup iface_wp_image_description_creator_params_v1
 *
 * Sets the maximum content light level (max_cll) as defined by CTA-861-H.
 *
 * This can only be set when set_tf_cicp is used to set the transfer
 * characteristic to Rec. ITU-R BT.2100-2 perceptual quantization system.
 * Otherwise, 'create' request shall raise inconsistent_set protocol
 * error.
 *
 * max_cll is undefined by default.
 */
static inline void
wp_image_description_creator_params_v1_set_max_cll(struct wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1, uint32_t max_cll)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_creator_params_v1,
			 WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_MAX_CLL, NULL, wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_params_v1), 0, max_cll);
}

/**
 * @ingroup iface_wp_image_description_creator_params_v1
 *
 * Sets the maximum frame-average light level (max_fall) as defined by
 * CTA-861-H.
 *
 * This can only be set when set_tf_cicp is used to set the transfer
 * characteristic to Rec. ITU-R BT.2100-2 perceptual quantization system.
 * Otherwise, 'create' request shall raise inconsistent_set protocol
 * error.
 *
 * max_fall is undefined by default.
 */
static inline void
wp_image_description_creator_params_v1_set_max_fall(struct wp_image_description_creator_params_v1 *wp_image_description_creator_params_v1, uint32_t max_fall)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_creator_params_v1,
			 WP_IMAGE_DESCRIPTION_CREATOR_PARAMS_V1_SET_MAX_FALL, NULL, wl_proxy_get_version((struct wl_proxy *) wp_image_description_creator_params_v1), 0, max_fall);
}

#ifndef WP_IMAGE_DESCRIPTION_V1_ERROR_ENUM
#define WP_IMAGE_DESCRIPTION_V1_ERROR_ENUM
/**
 * @ingroup iface_wp_image_description_v1
 * protocol errors
 */
enum wp_image_description_v1_error {
	/**
	 * attempted to use an object which is not ready
	 */
	WP_IMAGE_DESCRIPTION_V1_ERROR_NOT_READY = 0,
	/**
	 * get_information not allowed
	 */
	WP_IMAGE_DESCRIPTION_V1_ERROR_NO_INFORMATION = 1,
};
#endif /* WP_IMAGE_DESCRIPTION_V1_ERROR_ENUM */

#ifndef WP_IMAGE_DESCRIPTION_V1_CAUSE_ENUM
#define WP_IMAGE_DESCRIPTION_V1_CAUSE_ENUM
/**
 * @ingroup iface_wp_image_description_v1
 * generic reason for failure
 */
enum wp_image_description_v1_cause {
	/**
	 * interface version too low
	 */
	WP_IMAGE_DESCRIPTION_V1_CAUSE_LOW_VERSION = 0,
	/**
	 * unsupported image description data
	 */
	WP_IMAGE_DESCRIPTION_V1_CAUSE_UNSUPPORTED = 1,
};
#endif /* WP_IMAGE_DESCRIPTION_V1_CAUSE_ENUM */

/**
 * @ingroup iface_wp_image_description_v1
 * @struct wp_image_description_v1_listener
 */
struct wp_image_description_v1_listener {
	/**
	 * graceful error on creating the image description
	 *
	 * If creating a wp_image_description_v1 object fails for a
	 * reason that is not defined as a protocol error, this event is
	 * sent. The requests that create image description objects define
	 * whether and when this can occur. Only such creation requests can
	 * trigger this event. This event cannot be triggered after the
	 * image description was successfully formed.
	 *
	 * Once this event has been sent, the wp_image_description_v1
	 * object will never become ready and it can only be destroyed.
	 * @param cause generic reason
	 * @param msg ad hoc human-readable explanation
	 */
	void (*failed)(void *data,
		       struct wp_image_description_v1 *wp_image_description_v1,
		       uint32_t cause,
		       const char *msg);
	/**
	 * indication that the object is ready to be used
	 *
	 * Once this event has been sent, the wp_image_description_v1
	 * object is deemed "ready". Ready objects can be used to send
	 * requests and can be used through other interfaces.
	 *
	 * Every ready wp_image_description_v1 protocol object refers to an
	 * underlying image description record in the compositor. Multiple
	 * protocol objects may end up referring to the same record.
	 * Clients may identify these "copies" by comparing their id
	 * numbers: if the numbers from two protocol objects are identical,
	 * the protocol objects refer to the same image description record.
	 * Two different image description records cannot have the same id
	 * number simultaneously. The id number does not change during the
	 * lifetime of the image description record.
	 *
	 * The id number is valid only as long as the protocol object is
	 * alive. If all protocol objects referring to the same image
	 * description record are destroyed, the id number may be recycled
	 * for a different image description record.
	 *
	 * Image description id number is not a protocol object id. Zero is
	 * reserved as an invalid id number. It shall not be possible for a
	 * client to refer to an image description by its id number in
	 * protocol. The id numbers might not be portable between Wayland
	 * connections.
	 *
	 * This identity allows clients to de-duplicate image description
	 * records and avoid get_information request if they already have
	 * the image description information.
	 * @param identity image description id number
	 */
	void (*ready)(void *data,
		      struct wp_image_description_v1 *wp_image_description_v1,
		      uint32_t identity);
	/**
	 * end of information
	 *
	 * Signals the end of an information event sequence. This shall
	 * be sent only and exactly once for each get_information request
	 * on this object.
	 */
	void (*done)(void *data,
		     struct wp_image_description_v1 *wp_image_description_v1);
	/**
	 * ICC profile matching the image description
	 *
	 * This is an information event, see get_information.
	 *
	 * The icc argument provides a file descriptor to the client which
	 * may be memory-mapped to provide the ICC profile matching the
	 * image description. The fd is read-only, and if mapped then it
	 * must be mapped with MAP_PRIVATE by the client.
	 *
	 * The ICC profile version and other details are determined by the
	 * compositor. There is no provision for a client to ask for a
	 * specific kind of a profile.
	 * @param icc ICC profile file descriptor
	 * @param icc_size ICC profile size, in bytes
	 */
	void (*icc_file)(void *data,
			 struct wp_image_description_v1 *wp_image_description_v1,
			 int32_t icc,
			 uint32_t icc_size);
	/**
	 * primaries as chromaticity coordinates
	 *
	 * This is an information event, see get_information.
	 *
	 * Delivers the primary color volume primaries and white point
	 * using CIE 1931 xy chromaticity coordinates.
	 *
	 * Each coordinate value is multiplied by 10000 to get the argument
	 * value to carry precision of 4 decimals.
	 * @param r_x Red x * 10000
	 * @param r_y Red y * 10000
	 * @param g_x Green x * 10000
	 * @param g_y Green y * 10000
	 * @param b_x Blue x * 10000
	 * @param b_y Blue y * 10000
	 * @param w_x White x * 10000
	 * @param w_y White y * 10000
	 */
	void (*primaries)(void *data,
			  struct wp_image_description_v1 *wp_image_description_v1,
			  uint32_t r_x,
			  uint32_t r_y,
			  uint32_t g_x,
			  uint32_t g_y,
			  uint32_t b_x,
			  uint32_t b_y,
			  uint32_t w_x,
			  uint32_t w_y);
	/**
	 * H.273 ColourPrimaries code
	 *
	 * This is an information event, see get_information.
	 *
	 * This event provides the H.273 ColourPrimaries code matching the
	 * primary color volume primaries and white point of this image
	 * description.
	 * @param primaries_code H.273 ColourPrimaries code
	 */
	void (*primaries_cicp)(void *data,
			       struct wp_image_description_v1 *wp_image_description_v1,
			       uint32_t primaries_code);
	/**
	 * H.273 TransferCharacteristics code
	 *
	 * This is an information event, see get_information.
	 *
	 * This event provides the H.273 TransferCharacteristics code
	 * matching the transfer characteristics of this image description.
	 * @param tf_code H.273 TransferCharacteristics code
	 */
	void (*tf_cicp)(void *data,
			struct wp_image_description_v1 *wp_image_description_v1,
			uint32_t tf_code);
	/**
	 * transfer characteristic as a power curve
	 *
	 * This is an information event, see get_information.
	 *
	 * The color component transfer characteristic of this image
	 * description is a pure power curve. This event provides the
	 * exponent of the power function. This curve represents the
	 * conversion from electrical to optical pixel or color values.
	 *
	 * The curve exponent has been multiplied by 10000 to get the
	 * argument eexp value to carry the precision of 4 decimals.
	 * @param eexp the exponent * 10000
	 */
	void (*tf_power)(void *data,
			 struct wp_image_description_v1 *wp_image_description_v1,
			 uint32_t eexp);
	/**
	 * target primaries as chromaticity coordinates
	 *
	 * This is an information event, see get_information.
	 *
	 * Provides the color primaries and white point of the target color
	 * volume using CIE 1931 xy chromaticity coordinates. This is
	 * compatible with the SMPTE ST 2086 definition of HDR static
	 * metadata for mastering displays.
	 *
	 * While primary color volume is about how color is encoded, the
	 * target color volume is the actually displayable color volume. If
	 * target color volume is equal to the primary color volume, then
	 * this event is not sent.
	 *
	 * Each coordinate value is multiplied by 10000 to get the argument
	 * value to carry precision of 4 decimals.
	 * @param r_x Red x * 10000
	 * @param r_y Red y * 10000
	 * @param g_x Green x * 10000
	 * @param g_y Green y * 10000
	 * @param b_x Blue x * 10000
	 * @param b_y Blue y * 10000
	 * @param w_x White x * 10000
	 * @param w_y White y * 10000
	 */
	void (*target_primaries)(void *data,
				 struct wp_image_description_v1 *wp_image_description_v1,
				 uint32_t r_x,
				 uint32_t r_y,
				 uint32_t g_x,
				 uint32_t g_y,
				 uint32_t b_x,
				 uint32_t b_y,
				 uint32_t w_x,
				 uint32_t w_y);
	/**
	 * target luminance range
	 *
	 * This is an information event, see get_information.
	 *
	 * Provides the luminance range that the image description is
	 * targeting as the minimum and maximum absolute luminance L. This
	 * is compatible with the SMPTE ST 2086 definition of HDR static
	 * metadata.
	 *
	 * This luminance range is only theoretical and may not correspond
	 * to the luminance of light emitted on an actual display.
	 *
	 * Min L value is multiplied by 10000 to get the argument min_lum
	 * value and carry precision of 4 decimals. Max L value is unscaled
	 * for max_lum.
	 * @param min_lum min L (cd/m²) * 10000
	 * @param max_lum max L (cd/m²)
	 */
	void (*target_luminance)(void *data,
				 struct wp_image_description_v1 *wp_image_description_v1,
				 uint32_t min_lum,
				 uint32_t max_lum);
	/**
	 * target maximum content light level
	 *
	 * This is an information event, see get_information.
	 *
	 * Provides the targeted max_cll of the image description. max_cll
	 * is defined by CTA-861-H.
	 *
	 * This luminance is only theoretical and may not correspond to the
	 * luminance of light emitted on an actual display.
	 * @param max_cll Maximum content light-level (cd/m²)
	 */
	void (*target_max_cll)(void *data,
			       struct wp_image_description_v1 *wp_image_description_v1,
			       uint32_t max_cll);
	/**
	 * target maximum frame-average light level
	 *
	 * This is an information event, see get_information.
	 *
	 * Provides the targeted max_fall of the image description.
	 * max_fall is defined by CTA-861-H.
	 *
	 * This luminance is only theoretical and may not correspond to the
	 * luminance of light emitted on an actual display.
	 * @param max_fall Maximum frame-average light level (cd/m²)
	 */
	void (*target_max_fall)(void *data,
				struct wp_image_description_v1 *wp_image_description_v1,
				uint32_t max_fall);
};

/**
 * @ingroup iface_wp_image_description_v1
 */
static inline int
wp_image_description_v1_add_listener(struct wp_image_description_v1 *wp_image_description_v1,
				     const struct wp_image_description_v1_listener *listener, void *data)
{
	return wl_proxy_add_listener((struct wl_proxy *) wp_image_description_v1,
				     (void (**)(void)) listener, data);
}

#define WP_IMAGE_DESCRIPTION_V1_DESTROY 0
#define WP_IMAGE_DESCRIPTION_V1_GET_INFORMATION 1

/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_FAILED_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_READY_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_DONE_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_ICC_FILE_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_PRIMARIES_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_PRIMARIES_CICP_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_TF_CICP_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_TF_POWER_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_TARGET_PRIMARIES_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_TARGET_LUMINANCE_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_TARGET_MAX_CLL_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_TARGET_MAX_FALL_SINCE_VERSION 1

/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_wp_image_description_v1
 */
#define WP_IMAGE_DESCRIPTION_V1_GET_INFORMATION_SINCE_VERSION 1

/** @ingroup iface_wp_image_description_v1 */
static inline void
wp_image_description_v1_set_user_data(struct wp_image_description_v1 *wp_image_description_v1, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) wp_image_description_v1, user_data);
}

/** @ingroup iface_wp_image_description_v1 */
static inline void *
wp_image_description_v1_get_user_data(struct wp_image_description_v1 *wp_image_description_v1)
{
	return wl_proxy_get_user_data((struct wl_proxy *) wp_image_description_v1);
}

static inline uint32_t
wp_image_description_v1_get_version(struct wp_image_description_v1 *wp_image_description_v1)
{
	return wl_proxy_get_version((struct wl_proxy *) wp_image_description_v1);
}

/**
 * @ingroup iface_wp_image_description_v1
 *
 * Destroy this object. It is safe to destroy an object which is not ready.
 *
 * Destroying a wp_image_description_v1 object has no side-effects, not
 * even if a wp_color_management_surface_v1.set_image_description has
 * not yet been followed by a wl_surface.commit.
 */
static inline void
wp_image_description_v1_destroy(struct wp_image_description_v1 *wp_image_description_v1)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_v1,
			 WP_IMAGE_DESCRIPTION_V1_DESTROY, NULL, wl_proxy_get_version((struct wl_proxy *) wp_image_description_v1), WL_MARSHAL_FLAG_DESTROY);
}

/**
 * @ingroup iface_wp_image_description_v1
 *
 * As a reply to this request, the compositor shall send all matching
 * information events describing this image description object and finally
 * the 'done' event.
 *
 * Each information event may only be sent as a response to get_information
 * request, and it may only be sent once.
 *
 * Every get_information request on the same object shall always return the
 * exact same data.
 *
 * Not all image description protocol objects allow get_information
 * request. Whether it is allowed or not is defined by the request that
 * created the object. If get_information is not allowed, the protocol
 * error no_information is raised.
 */
static inline void
wp_image_description_v1_get_information(struct wp_image_description_v1 *wp_image_description_v1)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_image_description_v1,
			 WP_IMAGE_DESCRIPTION_V1_GET_INFORMATION, NULL, wl_proxy_get_version((struct wl_proxy *) wp_image_description_v1), 0);
}

#ifdef  __cplusplus
}
#endif

#endif
