/* Generated by wayland-scanner 1.22.0 */

#ifndef COLOR_REPRESENTATION_V1_CLIENT_PROTOCOL_H
#define COLOR_REPRESENTATION_V1_CLIENT_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-client.h"

#ifdef  __cplusplus
extern "C" {
#endif

/**
 * @page page_color_representation_v1 The color_representation_v1 protocol
 * color representation protocol extension
 *
 * @section page_desc_color_representation_v1 Description
 *
 * This protocol extension delivers the metadata required to define alpha mode,
 * the color model, sub-sampling and quantization range used when interpreting
 * buffer contents. The main use case is defining how the YUV family of pixel
 * formats convert to RGB.
 *
 * Note that this protocol does not define the colorimetry of the resulting RGB
 * channels / tristimulus values. Without the help of other extensions the
 * resulting colorimetry is therefore implementation defined.
 *
 * If this extension is not used, the color representation used is compositor
 * implementation defined.
 *
 * The code points used in this protocol are defined by Rec ITU-T H.273
 * Coding-independent code points for video signal type identification.
 *
 * @section page_ifaces_color_representation_v1 Interfaces
 * - @subpage page_iface_wp_color_representation_manager_v1 - color representation factory
 * - @subpage page_iface_wp_color_representation_v1 - color representation metadata
 * @section page_copyright_color_representation_v1 Copyright
 * <pre>
 *
 * Copyright 2022 Simon Ser
 * Copyright 2022 Red Hat, Inc.
 * Copyright 2022 Collabora, Ltd.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 * </pre>
 */
struct wl_surface;
struct wp_color_representation_manager_v1;
struct wp_color_representation_v1;

#ifndef WP_COLOR_REPRESENTATION_MANAGER_V1_INTERFACE
#define WP_COLOR_REPRESENTATION_MANAGER_V1_INTERFACE
/**
 * @page page_iface_wp_color_representation_manager_v1 wp_color_representation_manager_v1
 * @section page_iface_wp_color_representation_manager_v1_desc Description
 *
 * This global is a wp_color_representation_v1 factory.
 * @section page_iface_wp_color_representation_manager_v1_api API
 * See @ref iface_wp_color_representation_manager_v1.
 */
/**
 * @defgroup iface_wp_color_representation_manager_v1 The wp_color_representation_manager_v1 interface
 *
 * This global is a wp_color_representation_v1 factory.
 */
extern const struct wl_interface wp_color_representation_manager_v1_interface;
#endif
#ifndef WP_COLOR_REPRESENTATION_V1_INTERFACE
#define WP_COLOR_REPRESENTATION_V1_INTERFACE
/**
 * @page page_iface_wp_color_representation_v1 wp_color_representation_v1
 * @section page_iface_wp_color_representation_v1_desc Description
 *
 * This interface allows clients to set color representation metadata for a
 * surface.
 *
 * A wp_color_representation_v1 object is associated with a wl_surface. If
 * the wl_surface is destroyed first, the wp_color_representation_v1 object
 * becomes inert.
 * @section page_iface_wp_color_representation_v1_api API
 * See @ref iface_wp_color_representation_v1.
 */
/**
 * @defgroup iface_wp_color_representation_v1 The wp_color_representation_v1 interface
 *
 * This interface allows clients to set color representation metadata for a
 * surface.
 *
 * A wp_color_representation_v1 object is associated with a wl_surface. If
 * the wl_surface is destroyed first, the wp_color_representation_v1 object
 * becomes inert.
 */
extern const struct wl_interface wp_color_representation_v1_interface;
#endif

#ifndef WP_COLOR_REPRESENTATION_MANAGER_V1_ERROR_ENUM
#define WP_COLOR_REPRESENTATION_MANAGER_V1_ERROR_ENUM
enum wp_color_representation_manager_v1_error {
	/**
	 * color representation already constructed for this surface
	 */
	WP_COLOR_REPRESENTATION_MANAGER_V1_ERROR_ALREADY_CONSTRUCTED = 1,
};
#endif /* WP_COLOR_REPRESENTATION_MANAGER_V1_ERROR_ENUM */

/**
 * @ingroup iface_wp_color_representation_manager_v1
 * @struct wp_color_representation_manager_v1_listener
 */
struct wp_color_representation_manager_v1_listener {
	/**
	 * supported matrix coefficients
	 *
	 * This event advertises code points that the server supports.
	 * The code point defines one formula and the related constants
	 * used to derive red, green and blue signals, and the video full
	 * range flag.
	 *
	 * All the supported code points are advertised once when the
	 * client binds to this interface. A roundtrip after binding
	 * guarantees that the client has received all supported code
	 * points.
	 *
	 * For the definition of the code points, see the
	 * wp_color_representation_v1::set_coefficients request.
	 * @param code_point supported matrix coefficients and full range flag code point
	 */
	void (*coefficients)(void *data,
			     struct wp_color_representation_manager_v1 *wp_color_representation_manager_v1,
			     uint32_t code_point);
	/**
	 * supported chroma location
	 *
	 * This event advertises code points that the server supports.
	 * The code point represents one chroma location.
	 *
	 * All the supported code points are advertised once when the
	 * client binds to this interface. A roundtrip after binding
	 * guarantees that the client has received all supported code
	 * points.
	 *
	 * For the definition of the code points, see the
	 * wp_color_representation_v1::set_chroma_location request.
	 * @param code_point supported chroma location code point
	 */
	void (*chroma_location)(void *data,
				struct wp_color_representation_manager_v1 *wp_color_representation_manager_v1,
				uint32_t code_point);
};

/**
 * @ingroup iface_wp_color_representation_manager_v1
 */
static inline int
wp_color_representation_manager_v1_add_listener(struct wp_color_representation_manager_v1 *wp_color_representation_manager_v1,
						const struct wp_color_representation_manager_v1_listener *listener, void *data)
{
	return wl_proxy_add_listener((struct wl_proxy *) wp_color_representation_manager_v1,
				     (void (**)(void)) listener, data);
}

#define WP_COLOR_REPRESENTATION_MANAGER_V1_DESTROY 0
#define WP_COLOR_REPRESENTATION_MANAGER_V1_CREATE 1

/**
 * @ingroup iface_wp_color_representation_manager_v1
 */
#define WP_COLOR_REPRESENTATION_MANAGER_V1_COEFFICIENTS_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_representation_manager_v1
 */
#define WP_COLOR_REPRESENTATION_MANAGER_V1_CHROMA_LOCATION_SINCE_VERSION 1

/**
 * @ingroup iface_wp_color_representation_manager_v1
 */
#define WP_COLOR_REPRESENTATION_MANAGER_V1_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_representation_manager_v1
 */
#define WP_COLOR_REPRESENTATION_MANAGER_V1_CREATE_SINCE_VERSION 1

/** @ingroup iface_wp_color_representation_manager_v1 */
static inline void
wp_color_representation_manager_v1_set_user_data(struct wp_color_representation_manager_v1 *wp_color_representation_manager_v1, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) wp_color_representation_manager_v1, user_data);
}

/** @ingroup iface_wp_color_representation_manager_v1 */
static inline void *
wp_color_representation_manager_v1_get_user_data(struct wp_color_representation_manager_v1 *wp_color_representation_manager_v1)
{
	return wl_proxy_get_user_data((struct wl_proxy *) wp_color_representation_manager_v1);
}

static inline uint32_t
wp_color_representation_manager_v1_get_version(struct wp_color_representation_manager_v1 *wp_color_representation_manager_v1)
{
	return wl_proxy_get_version((struct wl_proxy *) wp_color_representation_manager_v1);
}

/**
 * @ingroup iface_wp_color_representation_manager_v1
 *
 * Destroy the manager object.
 *
 * Existing objects created through this interface remain valid.
 */
static inline void
wp_color_representation_manager_v1_destroy(struct wp_color_representation_manager_v1 *wp_color_representation_manager_v1)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_color_representation_manager_v1,
			 WP_COLOR_REPRESENTATION_MANAGER_V1_DESTROY, NULL, wl_proxy_get_version((struct wl_proxy *) wp_color_representation_manager_v1), WL_MARSHAL_FLAG_DESTROY);
}

/**
 * @ingroup iface_wp_color_representation_manager_v1
 *
 * Create a wp_color_representation_v1 object tied to a wl_surface.
 *
 * If a wp_color_representation_v1 object already exists for this surface,
 * the already_constructed protocol error must be sent by the compositor.
 */
static inline struct wp_color_representation_v1 *
wp_color_representation_manager_v1_create(struct wp_color_representation_manager_v1 *wp_color_representation_manager_v1, struct wl_surface *surface)
{
	struct wl_proxy *color_representation;

	color_representation = wl_proxy_marshal_flags((struct wl_proxy *) wp_color_representation_manager_v1,
			 WP_COLOR_REPRESENTATION_MANAGER_V1_CREATE, &wp_color_representation_v1_interface, wl_proxy_get_version((struct wl_proxy *) wp_color_representation_manager_v1), 0, NULL, surface);

	return (struct wp_color_representation_v1 *) color_representation;
}

#ifndef WP_COLOR_REPRESENTATION_V1_ERROR_ENUM
#define WP_COLOR_REPRESENTATION_V1_ERROR_ENUM
enum wp_color_representation_v1_error {
	/**
	 * invalid alpha mode
	 */
	WP_COLOR_REPRESENTATION_V1_ERROR_INVALID_ALPHA_MODE = 1,
	/**
	 * unsupported coefficients
	 */
	WP_COLOR_REPRESENTATION_V1_ERROR_UNSUPPORTED_COEFFICIENTS = 2,
	/**
	 * unsupported chroma_location
	 */
	WP_COLOR_REPRESENTATION_V1_ERROR_UNSUPPORTED_CHROMA_LOCATION = 3,
	/**
	 * the pixel format and a code point are incompatible
	 */
	WP_COLOR_REPRESENTATION_V1_ERROR_INCOMPATIBLE_PIXEL_FORMAT = 4,
};
#endif /* WP_COLOR_REPRESENTATION_V1_ERROR_ENUM */

#ifndef WP_COLOR_REPRESENTATION_V1_ALPHA_MODE_ENUM
#define WP_COLOR_REPRESENTATION_V1_ALPHA_MODE_ENUM
/**
 * @ingroup iface_wp_color_representation_v1
 * alpha mode
 *
 * Specifies how the alpha channel affects the color channels.
 */
enum wp_color_representation_v1_alpha_mode {
	/**
	 * premultiplied alpha in electrical values
	 *
	 * Electrical color channel values (after transfer function
	 * encoding) are already multiplied with the alpha channel value.
	 */
	WP_COLOR_REPRESENTATION_V1_ALPHA_MODE_PREMULTIPLIED_ELECTRICAL = 0,
	/**
	 * premultiplied alpha in optical values
	 *
	 * Optical color channel values (before transfer function
	 * encoding) are already multiplied with the alpha channel value.
	 */
	WP_COLOR_REPRESENTATION_V1_ALPHA_MODE_PREMULTIPLIED_OPTICAL = 1,
	/**
	 * straight alpha
	 *
	 * Alpha channel has not been pre-multiplied into color channels.
	 */
	WP_COLOR_REPRESENTATION_V1_ALPHA_MODE_STRAIGHT = 2,
};
#endif /* WP_COLOR_REPRESENTATION_V1_ALPHA_MODE_ENUM */

#define WP_COLOR_REPRESENTATION_V1_DESTROY 0
#define WP_COLOR_REPRESENTATION_V1_SET_ALPHA_MODE 1
#define WP_COLOR_REPRESENTATION_V1_SET_COEFFICIENTS 2
#define WP_COLOR_REPRESENTATION_V1_SET_CHROMA_LOCATION 3


/**
 * @ingroup iface_wp_color_representation_v1
 */
#define WP_COLOR_REPRESENTATION_V1_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_representation_v1
 */
#define WP_COLOR_REPRESENTATION_V1_SET_ALPHA_MODE_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_representation_v1
 */
#define WP_COLOR_REPRESENTATION_V1_SET_COEFFICIENTS_SINCE_VERSION 1
/**
 * @ingroup iface_wp_color_representation_v1
 */
#define WP_COLOR_REPRESENTATION_V1_SET_CHROMA_LOCATION_SINCE_VERSION 1

/** @ingroup iface_wp_color_representation_v1 */
static inline void
wp_color_representation_v1_set_user_data(struct wp_color_representation_v1 *wp_color_representation_v1, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) wp_color_representation_v1, user_data);
}

/** @ingroup iface_wp_color_representation_v1 */
static inline void *
wp_color_representation_v1_get_user_data(struct wp_color_representation_v1 *wp_color_representation_v1)
{
	return wl_proxy_get_user_data((struct wl_proxy *) wp_color_representation_v1);
}

static inline uint32_t
wp_color_representation_v1_get_version(struct wp_color_representation_v1 *wp_color_representation_v1)
{
	return wl_proxy_get_version((struct wl_proxy *) wp_color_representation_v1);
}

/**
 * @ingroup iface_wp_color_representation_v1
 *
 * Destroy the color representation metadata object.
 *
 * Destroying this object unsets all the color representation metadata for
 * the surface. The color representation transformations for the surface
 * are implementation defined when no code point is set. The alpha mode
 * becomes premultiplied_electrical.
 *
 * Unsetting the color representation is double-buffered, see
 * wl_surface.commit.
 */
static inline void
wp_color_representation_v1_destroy(struct wp_color_representation_v1 *wp_color_representation_v1)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_color_representation_v1,
			 WP_COLOR_REPRESENTATION_V1_DESTROY, NULL, wl_proxy_get_version((struct wl_proxy *) wp_color_representation_v1), WL_MARSHAL_FLAG_DESTROY);
}

/**
 * @ingroup iface_wp_color_representation_v1
 *
 * Assuming an alpha channel exists, it is always linear. The alpha mode
 * determines whether and how the color channels include pre-multiplied
 * alpha. Using straight alpha might have performance benefits.
 *
 * The "alpha_mode" argument must be a valid enum entry, otherwise the
 * "invalid_alpha_mode" protocol error is raised.
 *
 * Alpha mode is double buffered, see wl_surface.commit.
 *
 * By default, a surface is assumed to be premultiplied_electrical.
 */
static inline void
wp_color_representation_v1_set_alpha_mode(struct wp_color_representation_v1 *wp_color_representation_v1, uint32_t alpha_mode)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_color_representation_v1,
			 WP_COLOR_REPRESENTATION_V1_SET_ALPHA_MODE, NULL, wl_proxy_get_version((struct wl_proxy *) wp_color_representation_v1), 0, alpha_mode);
}

/**
 * @ingroup iface_wp_color_representation_v1
 *
 * Set the code point which defines the formula and the related constants
 * used to derive red, green and blue signals, and the video full range
 * flag.
 *
 * Only code points advertised by the compositor are allowed to be used as
 * argument for this request. The "unsupported_coefficients" protocol error
 * is raised otherwise.
 *
 * Bits 7 down to 0 represent a MatrixCoefficients code point as defined in
 * Rec ITU-T H.273. Bit 8 represents the VideoFullRangeFlag flag as defined
 * in Rec ITU-T H.273.
 *
 * A call to wl_surface.commit verifies that the pixel format and
 * MatrixCoefficients code point in the committed surface contents are
 * compatible if contents exist. The "incompatible_pixel_format" protocol
 * error is raised otherwise.
 *
 * A pixel format is compatible with a MatrixCoefficients code point if the
 * equations and conventions listed for the chosen code point (and
 * VideoFullRangeFlag) in Rec ITU-T H.273 can produce the color channels
 * (RGB or YCbCr) of the pixel format.
 *
 * The code point is double-buffered, see wl_surface.commit.
 */
static inline void
wp_color_representation_v1_set_coefficients(struct wp_color_representation_v1 *wp_color_representation_v1, uint32_t code_point)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_color_representation_v1,
			 WP_COLOR_REPRESENTATION_V1_SET_COEFFICIENTS, NULL, wl_proxy_get_version((struct wl_proxy *) wp_color_representation_v1), 0, code_point);
}

/**
 * @ingroup iface_wp_color_representation_v1
 *
 * Set the code point which defines the position of downsampled chroma
 * samples.
 *
 * Only code points advertised by the compositor are allowed to be used as
 * argument for this request. The "unsupported_chroma_location" protocol
 * error is raised otherwise.
 *
 * The argument is a Chroma420SampleLocType code point as defined in Rec
 * ITU-T H.273.
 *
 * A call to wl_surface.commit verifies that the pixel format and
 * Chroma420SampleLocType code point in the committed surface contents are
 * compatible if contents exist. The "incompatible_pixel_format" protocol
 * error is raised otherwise.
 *
 * A pixel format is compatible with a Chroma420SampleLocType code point if
 * the pixel format is a 4:2:0 subsampled color format.
 *
 * The code point is double-buffered, see wl_surface.commit.
 */
static inline void
wp_color_representation_v1_set_chroma_location(struct wp_color_representation_v1 *wp_color_representation_v1, uint32_t code_point)
{
	wl_proxy_marshal_flags((struct wl_proxy *) wp_color_representation_v1,
			 WP_COLOR_REPRESENTATION_V1_SET_CHROMA_LOCATION, NULL, wl_proxy_get_version((struct wl_proxy *) wp_color_representation_v1), 0, code_point);
}

#ifdef  __cplusplus
}
#endif

#endif
